@@ -1,15 +1,19 @@
-// holochain-rsm utils //
+//! holochain-rsm utils
+//!
 pub mod commit_idempotent;
 pub use commit_idempotent::commit_idempotent;
 pub mod create_idempotent_link;
 pub use create_idempotent_link::create_idempotent_link;
-pub mod error;
-pub use error::{UtilsError, UtilsResult};
 pub mod exists;
 pub use exists::exists;
 pub mod get_header;
 pub use get_header::get_header;
+pub mod get;
+pub use get::get;
+pub mod get_details;
+pub use get_details::get_details;
 pub mod get_latest_entry;
+pub use get_latest_entry::get_latest_entries;
 pub use get_latest_entry::get_latest_entry;
 pub mod get_latest_link;
 pub use get_latest_link::get_latest_link;
@@ -19,12 +23,12 @@ pub mod remove_link;
 pub use remove_link::remove_link;
 pub mod local_source_chain;
 pub use local_source_chain::local_source_chain;
-// pub mod entry_id_to_index;
-// pub use entry_id_to_index::entry_id_to_index;
-// pub mod entry_id_to_app_entry_type;
-// pub use entry_id_to_app_entry_type::entry_id_to_app_entry_type;
+
 pub mod wrappers;
 pub use wrappers::WrappedAgentPubKey;
 pub use wrappers::WrappedDnaHash;
 pub use wrappers::WrappedEntryHash;
 pub use wrappers::WrappedHeaderHash;
+
+pub mod error;
+pub use error::{UtilsError, UtilsResult};
